# Introduction

This is the documentation for restframework-rdf, a django app that manages integration between django-rest-framework and and RDF database.

- [Getting started](/getting-started)
- RDF
    - [Migrations](/rdf/migrations)
    - [Namespaces](/rdf/namespaces)
    - [Parsers](/rdf/parsers)
    - [Views](/rdf/views)
- SPARQL
    - [Making SPARQL endpoints](/sparql/making-sparql-endpoints)
    - [Views](sparql/views)
    - [Renderers](/sparql/renderers)